import csv
import bs4
import codecs
import os, sys, string, warnings
from itertools import islice
import time


# Hiermit können Artikeltexte (Reintext) aus einem HTML-Code extrahiert und in einer CSV-Datei gespeichert werden.
# Dabei wird ein Artikeltext anhand der bestimmten HTML-Tags in dem jeweiligen HTML-Code gefunden. In jeder Zeitung 
# werden verschiedene HTML-Tags benutzt. Anschlißend wird der HTML-Code mit dem gefundenen Reintext ersetzt und in 
# in einer CSV-Datei gespeichert. Dabei ist die folgende Struktur zu beachten:
#
# Die gecrawlten CSV-Dateien sind folgendermassen aufgebaut:
# 1. Zeile: "Timetag","RSS","URL","html-Seite 1"
# 2. Zeile: "Timetag","RSS","URL","html-Seite 2"
# usw.
#
# Die "extrahierten" CSV-Dateien sind folgendermassen aufgebaut:
# 1. Zeile: "Timetag","RSS","URL","Artikeltext 1"
# 2. Zeile: "Timetag","RSS","URL","Artikeltext 2"
# usw.
#
# Aufruf: python Converter.py /path/to/website_downloads_YYYY-MM-DD.csv website_downloads_YYYY-MM-DD

## Notwendig, um die langen HTML-Texte ablesen zu koennen. 
maxInt = sys.maxsize
decrement = True

while decrement:
    # decrease the maxInt value by factor 10 
    # as long as the OverflowError occurs.

    decrement = False
    try:
        csv.field_size_limit(maxInt)
    except OverflowError:
        maxInt = int(maxInt/10)
        decrement = True

warnings.filterwarnings("ignore", category=UserWarning, module="bs4")


## HTML-Converter:
def text_extract(file_to_extract):

  with open(file_to_extract, newline='', encoding="utf-8") as input_file, open("./extracted/extracted_" + sys.argv[2] + ".csv", 'w') as output_file:
    reader = csv.reader(input_file)
    writer = csv.writer(output_file, delimiter=',', quoting=csv.QUOTE_ALL)
    
    # Lese bestimmte Anzahl von Zeilen ab:
    #for line in islice(reader, 200):
    for line in reader: # csv wird zeilenweise abgelesen - line = Zeile 1 usw. 

      #BeautifulSoup-Teil

      html=line[3].encode(encoding="utf-8").decode(encoding='unicode_escape', errors="restrict") #decode/encode um Sonderzeichen auszublenden, z.B. \n oder \t... 
      html_text=bs4.BeautifulSoup(html, "lxml")

      ########################## Hier wird die if-Abfrage fuer verschiedenen Webseiten durchgefuehrt
      

      ############################################################## AU News ############################################################

      ### Advertiser Australia
      if line[1].startswith("http://rssfeeds.theadvertiser.com"):
        if html_text.find_all(name="p", attrs={"class": "p-text"}):

          whole_text = html_text.find_all(name="p", attrs={"class": "p-text"})
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"AU","The Advertiser",artikel]) # schreibt alles in einer Zeile von der output-Datei



      ### Daily Telegraph Australia
      elif line[1].startswith("http://www.dailytelegraph.com.au"):

        if html_text.find(name="div", attrs={"class": "tg-tlc-storybody cf"}):

          whole_text = html_text.find(name="div", attrs={"class": "tg-tlc-storybody cf"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"AU","The Daily Telegraph AU",artikel]) # schreibt alles in einer Zeile von der output-Datei



      ### Herald Sun Australia FUNK NICHT
      elif line[1].startswith("http://www.heraldsun.com.au"):

        if html_text.find(name="article", attrs={"class": "article-content"}):
        #if html_text.find(name="article", attrs={"itemprop": "articleBody"}):

          whole_text = html_text.find(name="article", attrs={"class": "article-content"}).find_all(name="p")
          #whole_text = html_text.find(name="article", attrs={"itemprop": "articleBody"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"AU","Herald Sun",artikel]) # schreibt alles in einer Zeile von der output-Datei



      ### The Age Australia FUNK NICHT
      elif line[1].startswith("http://www.theage.com.au"):

        if html_text.find(name="div", attrs={"class": "article_body"}):

          whole_text = html_text.find(name="div", attrs={"class": "article_body"}).find_all(name="p")
          #whole_text = html_text.find(name="div", attrs={"itemprop": "articleBody"}).find_all("p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"AU","The Age",artikel]) # schreibt alles in einer Zeile von der output-Datei


      ### Canberra Times Australia FUNK NICHT 
      elif line[1].startswith("http://www.canberratimes.com.au"):

        if html_text.find(name="div", attrs={"class": "article__body"}):

          whole_text = html_text.find(name="div", attrs={"class": "article__body"}).find_all(name="p")
          #whole_text = html_text.find(name="div", attrs={"itemprop": "articleBody"}).find_all("p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"AU","Canberra Times",artikel]) # schreibt alles in einer Zeile von der output-Datei


      ### Mercury Australia
      elif line[1].startswith("http://www.themercury.com.au"):

        #if html_text.find(name="div", attrs={"class": "tg-tlc-storybody cf"}):
        #  whole_text = html_text.find(name="div", attrs={"class": "tg-tlc-storybody cf"}).find_all(name="p")
        if html_text.find(name="div", attrs={"class": "content"}):
          whole_text = html_text.find(name="div", attrs={"class": "content"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"AU","The Mercury",artikel]) # schreibt alles in einer Zeile von der output-Datei


      ### ABC Australia
      elif line[1].startswith("http://www.abc.net.au"):
        if html_text.find(name="div", attrs={"class": "article section"}):
          whole_text = html_text.find(name="div", attrs={"class": "article section"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"AU","ABC Australia",artikel]) # schreibt alles in einer Zeile von der output-Datei



      ### The West Australia
      elif line[1].startswith("https://thewest.com.au"):
        if html_text.find_all(name="p", attrs={"class": "css-1rgmj8p"}):
          whole_text = html_text.find_all(name="p", attrs={"class": "css-1rgmj8p"})
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"AU","The west australian",artikel]) # schreibt alles in einer Zeile von der output-Datei



      ### News Australia
      elif line[1].startswith("http://www.news.com.au"):
        if html_text.find(name="div", attrs={"id": "story"}):
          whole_text = html_text.find(name="div", attrs={"id": "story"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"AU","News Australia",artikel]) # schreibt alles in einer Zeile von der output-Datei


      ################################################################ Germany News #######################################################

      ### Spiegel
      elif line[1].startswith("https://www.spiegel.de"):
        if html_text.find(name="div", attrs={"class": "spArticleContent"}):
          whole_text = html_text.find(name="div", attrs={"class": "SpArticleContent"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"DE","Spiegel Online",artikel]) # schreibt alles in einer Zeile von der output-Datei


     ############################################################ UK News ##################################################################

      ### Independent
      elif line[1].startswith("http://www.independent.co.uk"):
        if html_text.find(name="div", attrs={"class": "text-wrapper"}):
          whole_text = html_text.find(name="div", attrs={"class": "text-wrapper"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"UK","The Independent",artikel]) # schreibt alles in einer Zeile von der output-Datei



      ### The Guardian
      elif line[1].startswith("https://www.theguardian.com"):
        if html_text.find(name="div", attrs={"itemprop": "articleBody"}):
          whole_text = html_text.find(name="div", attrs={"itemprop": "articleBody"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"UK","The Guardian",artikel]) # schreibt alles in einer Zeile von der output-Datei
    


      ### BBC News UK 
      elif line[1].startswith("http://feeds.bbci.co.uk/news/rss"):
        if html_text.find(name="div", attrs={"property": "articleBody"}):
          whole_text = html_text.find(name="div", attrs={"property": "articleBody"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"UK","BBC News",artikel]) # schreibt alles in einer Zeile von der output-Datei
    

      ### Daily Express UK
      elif line[1].startswith("http://feeds.feedburner.com"):
        if html_text.find(name="div", attrs={"data-type": "article-body"}):
          whole_text = html_text.find(name="div", attrs={"data-type": "article-body"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"UK","Daily Express",artikel]) # schreibt alles in einer Zeile von der output-Datei


      ### Daily Mail UK
      elif line[1].startswith("http://www.dailymail.co.uk"):
        if html_text.find(name="div", attrs={"class": "articleWide cleared"}):
          whole_text = html_text.find(name="div", attrs={"class": "articleWide cleared"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"UK","Daily Mail",artikel]) # schreibt alles in einer Zeile von der output-Datei


      ### Evening Standard UK
      elif line[1].startswith("https://www.standard.co.uk"):
        if html_text.find(name="div", attrs={"class": "body-content"}):
          whole_text = html_text.find(name="div", attrs={"class": "body-content"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"UK","Evening Standard",artikel]) # schreibt alles in einer Zeile von der output-Datei
    

      ### Financial Times UK
      elif line[1].startswith("https://www.ft.com"):
        if html_text.find(name="section", attrs={"itemprop": "articleBody"}):
          whole_text = html_text.find(name="section", attrs={"itemprop": "articleBody"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"UK","Financial Times",artikel]) # schreibt alles in einer Zeile von der output-Datei



     ################################################## US News #########################################################################
      ### BBC News  US
      elif line[1].startswith("http://feeds.bbci.co.uk/news/world/us_and_canada"):
        if html_text.find(name="div", attrs={"property": "articleBody"}):
          whole_text = html_text.find(name="div", attrs={"property": "articleBody"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","BBC US",artikel]) # schreibt alles in einer Zeile von der output-Datei


      # ### NPR US
      elif line[1].startswith("http://www.npr.org/"):
        if html_text.find(name="div", attrs={"id": "storytext"}):
          whole_text = html_text.find(name="div", attrs={"id": "storytext"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","NPR",artikel]) # schreibt alles in einer Zeile von der output-Datei



      ### Reuters US + World + Politics
      elif line[1].startswith("http://feeds.reuters.com"):
        if html_text.find(name="div", attrs={"class": "StandardArticleBody_body_1gnLA"}):
          whole_text = html_text.find(name="div", attrs={"class": "StandardArticleBody_body_1gnLA"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","Reuters",artikel]) # schreibt alles in einer Zeile von der output-Datei

     

      ### New York Times US + World
      elif line[1].startswith("http://rss.nytimes.com"):
        if html_text.find(name="div", attrs={"class": "story-body story-body-1"}):
          whole_text = html_text.find(name="div", attrs={"class": "story-body story-body-1"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","New York Times",artikel]) # schreibt alles in einer Zeile von der output-Datei

      
      ### CNN US + World
      elif line[1].startswith("http://rss.cnn.com"):
        #if html_text.find(name="div", attrs={"class": "l-container"}):
          #whole_text = html_text.find(name="div", attrs={"class": "l-container"}).find_all(name="p")
        if html_text.find(name="div", attrs={"itemprop": "articleBody"}):
          whole_text = html_text.find(name="div", attrs={"itemprop": "articleBody"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","CNN",artikel]) # schreibt alles in einer Zeile von der output-Datei

    

      ### Associated Press US + World + Politics
      elif line[1].startswith("http://hosted2.ap.org"):
        if html_text.find(name="div", attrs={"class": "articleBody"}):
          whole_text = html_text.find(name="div", attrs={"class": "articleBody"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","Associated Press",artikel]) # schreibt alles in einer Zeile von der output-Datei

      

      ### Washington Post US + World + Politics
      elif line[1].startswith("http://feeds.washingtonpost.com/rss"):
        if html_text.find(name="div", attrs={"id": "article-body"}):
          whole_text = html_text.find(name="div", attrs={"id": "article-body"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","Washington Post",artikel]) # schreibt alles in einer Zeile von der output-Datei

      

      ### FOX News US + Worls + Politics
      elif line[2].startswith("http://feeds.foxnews.com"):
        if html_text.find(name="div", attrs={"class": "article-body"}):
          whole_text = html_text.find(name="div", attrs={"class": "article-body"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","Fox News",artikel]) # schreibt alles in einer Zeile von der output-Datei

     


      ### MSNBC US
      elif line[1].startswith("http://www.msnbc.com"):
        if html_text.find(name="section", attrs={"itemprop": "articleBody"}):
          whole_text = html_text.find(name="section", attrs={"itemprop": "articleBody"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","MSNBC",artikel]) # schreibt alles in einer Zeile von der output-Datei




      ### CBS US + World + Politics 
      elif line[1].startswith("https://www.cbsnews.com"):
        #if html_text.find(name="div", attrs={"class": "content-primary article-page default"}):
          #whole_text = html_text.find(name="div", attrs={"class": "content-primary article-page default"}).find_all(name="p")
        if html_text.find(name="article", attrs={"id": "article"}):
          whole_text = html_text.find(name="article", attrs={"id": "article"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","CBS",artikel]) # schreibt alles in einer Zeile von der output-Datei



      
      ### ABC News US + World + Politics + International
      elif line[1].startswith("http://abcnews.go.com"):
        if html_text.find_all(name="p", attrs={"itemprop": "articleBody"}):
          whole_text = html_text.find_all(name="p", attrs={"itemprop": "articleBody"})
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","ABC News",artikel]) # schreibt alles in einer Zeile von der output-Datei

    


       ### Wallstreet Journal US
      elif line[1].startswith("https://www.wsj.com"):
        if html_text.find(name="div", attrs={"id": "article_sector"}):
          whole_text = html_text.find(name="div", attrs={"id": "article_sector"}).find_all(name="p")
          extracted_text = []
        
          # Jeder gefundene Tag wird einzeln abgelesen
          for zeile in whole_text:
            tag_text = zeile.get_text() 

            # hier werden leere Zeilen, tabs und returns aus dem Tag geloescht
            tag_text = tag_text.replace("\r", "").replace("\n", "")
          
            # hier wird jeder Tag zu einer Liste hinzugefuegt
            extracted_text.append(tag_text)

          artikel=" ".join(extracted_text) # joint alle Elemente aus der Liste zu einem grossen Sting (Separated mit " ")
       
          writer.writerow([line[0],line[2],"US","Wallstreet Journal",artikel]) # schreibt alles in einer Zeile von der output-Datei

# schliesst die Dateien
  input_file.close()
  output_file.close()

def main():
  if len(sys.argv) == 3:
    text_extract(sys.argv[1])
  else:
    print("Wrong parameters: python3 Converter.py /path/to/website_downloads_YYYY-MM-DD.csv website_downloads_YYYY-MM-DD")
    return

if __name__ == "__main__":
  main()
