### Import der verschiedenen Python Bibliotheken

import matplotlib.pyplot as plt
%pylab inline
import pandas as pd
import numpy as np
from nltk.corpus import stopwords
from nltk.tokenize import word_tokenize
import string
import unicodedata
import sys
from nltk.stem.wordnet import WordNetLemmatizer
from nltk import pos_tag
from nltk.corpus import wordnet
from collections import Counter
from nltk.corpus import state_union
from nltk.tokenize import PunktSentenceTokenizer
from sklearn.feature_extraction.text import CountVectorizer
from sklearn.metrics.pairwise import euclidean_distances
from sklearn.metrics.pairwise import cosine_similarity
import nltk
import collections
import seaborn as sns
import os 
import matplotlib.pyplot as plt
from sklearn.manifold import MDS
from scipy.cluster.hierarchy import ward, dendrogram

### Importieren des Dataframes_all und jeweiliges aufsplitten in Länder spezifische Dataframes

df = pd.read_pickle(".\dataframe_all")
uk_dataframe = df[df["Country"]=="UK"]
us_dataframe = df[df["Country"]=="US"]
au_dataframe = df[df["Country"]=="AU"]

### Start mit den Ähnlichkeitsanalysen

### Part of Speech ###
### https://www.ling.upenn.edu/courses/Fall_2003/ling001/penn_treebank_pos.html
### Bei Part of Speech geben wir die durschnittliche Anzahl an Wortarten pro Land aus. 

### In dieser Methode werden die Sätze in einzelne Tokens umgewandelt.
### Im nächsten Schritt wird jedem einzelnen Token eine Wortart (pos_tag) hinzugefügt.
### Hierfür wird eine for Schleife durchlaufen die Anfangs ein leeres Array beinhaltet.
### Innerhalb der Schleife wird jedes vorher tokenizede Wort mit einem pos_tag versehen und in dem Array gespeichert,
### sodass dieses Array langsam mit den Wörtern und der zugehörigen Wortart gespeichert wird. Wir erhalten jeweils einen String
### aus Wort und Wortart.

def pos(article):
    custom_sent_tokenizer = PunktSentenceTokenizer(article)
    tokenized = custom_sent_tokenizer.tokenize(article)
    tag_text=[]
    p=0
    for i in tokenized:
        words = nltk.word_tokenize(i)             
        tag = nltk.pos_tag(words)            
        tokenized[p] = tag
        p = p+1
        tag_text = tokenized

    return tag_text

### Innerhalb der for Schleife wird die Methode pos(article) aufgerufen. Auch hier wird wieder ein leeres Array initialisiert,
### welches die POS tags der einzelnen Artikel(Wörter) nach und nach speichert.
### Damit wir einen Durschnittswert pro Artikel erhalten, teilen wir die ermittelten POS Tags pro Artikel
### durch die Anzahl der Artikel im Dataframe. Anschließend benennen wir die Berechnete Zeile in Amount (in der Dokumentation
### noch Number um) um. Damit wir nur die Top 10 POS Wortarten angezeigt bekommen beschränken wir unsere Ausgabe
### durch iloc auf die ersten 10 ermittelten Index Einträge.

tags = []

for index, article in uk_dataframe["Article"].iteritems():
    for i in pos(article):
        for a, b in i:
            tags.append(b)
 
tags = pd.Series(tags)
df_pos = pd.DataFrame(tags.value_counts()/uk_dataframe["Article"].count()).transpose() 
df_pos.rename(index={0:'Amount'}, inplace=True)
df_pos.iloc[:,0:10] 

### Bag of Words / nicht verwendeter Code(erster Ansatz) aber funktionierend.###

### Wandelt das Dataframe in einen Countvektor um. Der die Wörter der Artikel in einem Sack(BOW) speichert. 
### Dabei werden die Wörter in Zahlen umgewandelt und können nicht mehr identifizert werden. Daher ist diese Implementierung
### für uns relativ nutzlos gewesen.

to_bow = CountVectorizer().fit(us_dataframe["Article"].values.astype('U'))

### Gibt die Wortanzahl der unique Wörter unseres erzeugten BOW aus

print(len(to_bow.vocabulary_))

### Wandelt das Dataframe in ein BOW um. 

bow = to_bow.transform([us_dataframe["Article"][4]])

### Gibt das Wort als Wort aus, welches sich an Stelle X im Vektor befindet.

print(to_bow.get_feature_names()[5203])

### Gibt die Stelle im Vektor aus, an dessen Stelle sich das definierte Wort befindet.

print(to_bow.vocabulary_.get('usa'))

### Bag of Words && Top10 BOW Wörter / Verwendeter Code ###

counter = collections.Counter()

### Die Methode BOW, zählt die Anzahl an Wörten in allen Artikeln des Landes zusammen.
### Hierfür wird ein Counter initialisiert, welcher in einer For Schleife jedes Wort innerhalb der Artikel durch 
### iteriert und den Wert um einen hochzaehlt, sodass wir am Ende ein String erhalten, welches das Wort, sowie 
### die Anzahl seiner Vorkommnis beihnaltet.

def BOW(article):
    joined = ''.join(article)
    words = joined.split()
    for word in words:
        counter[word] += 1
    print(counter)
    
BOW(us_dataframe["Article"])

### Die Methode Top Words, zählt die Anzahl an Top 10 Wörtern pro Land zusammen.
### Analog zur vorherigen Methode "BOW", allerdings kann ein weiterer Parameter mit gegeben werden, der angibt welche 
### Top Anzahl von Wörtern man sehen will. In diesem Fall haben wir uns auf das Vorkommen der Top 10 Wörter festgelegt.

def TopBOW(article, TopNumber):
    joined = ''.join(article)
    words = joined.split()
    for word in words:
        counter[word] += 1
    TOP = (counter.most_common(TopNumber))
    return(TOP)
        
TopBOW(us_dataframe["Article"], 10)

### Visualisierung Top 10 BOW Wörter ###

### Initialisiert die Variable counts mit der Methode Top BOW

counts = TopBOW(us_dataframe["Article"], 10) 

### Hier erstellen wir ein Diagramm mit x und y Achse. Dabei iteriert wir über alle Wörter in counts und über alle
### Werte in counts auf der jeweiligen Achse. Anschließend ordnen wir die Werte der entsprechenden x und y Achse zu. 
### Das Alpha gibt dabei die Transparenz der Bars an. 

sns.set()

word =[x[0] for x in counts] 
value = [int(y[1]) for y in counts] 
mybar = plt.bar(word, value, alpha=0.5, color="green")

### Beschriftung der x und y Achse, sowie des Titels und der gewünschten Schriftgröße.

plt.xlabel("Top Words", fontsize=15) 
plt.ylabel("Amount", fontsize=15) 
plt.title("Top 10 Words US", fontsize=15)

### Nimmt die momentane größe des Diagramms an und setzt die fig_siz, also die Skalierung des Diagrammes an.
### Anschließend wird das Diagramm geplotted und angezeigt.

fig_size = plt.rcParams["figure.figsize"]
 
fig_size[0] = 12
fig_size[1] = 9
plt.rcParams["figure.figsize"] = fig_size 

plt.show()

# Hilfsmethoden für die Berechnung von TF-IDF: ###

# Anzahl eines Wortes in einem Dokument, angepasst an die Länge des Dokumentes

def tf(word, doc):
    return doc.split().count(word) / len(doc.split())

# Logarithmus von (Anzahl Dokumente / Anzahl Dokumenten in denen Wort vorkommt), 1+ um nicht durch 0 zu teilen,
# falls ein Wort mal nicht in einem Dokument vorkommt

def idf(word, doclist):
    contains_word = sum(1 for doc in doclist if word in doc.split())
    return math.log(len(doclist) / (1 + contains_word)) 

# Berechnet TF-IDF-Wert für ein Wort

def tfidf(word, doc, doclist):
    return tf(word, doc) * idf(word, doclist)

# Zusammengeführt in Hauptmethode:
# Erstellt ein Dictionary mit Wort als Key, TF-IDF-Wert als Value

def tfidf_scores(doclist):
    for doc in doclist:
        scores = {word: tfidf(word, doc, doclist) for word in doc.split()}
    return scores
sorted_scores = sorted(tfidf_scores(au_dataframe['Article'].head(5)).items(), key=lambda x: x[1], reverse=True)
sorted_scores[:10]

### Visualisierung der Tfidf Berechnungen ###

### Diagram Top Wörter per Land basierend auf TF-IDF-Wert
# Erst werden die Werte in absteigender Folge sortiert, für doclist wird ein Dataframe mit Spalte "Article" übergeben
# sorted_scores gibt eine Liste mit Tupeln zurück (Wort, TF-IDF), absteigend sortiert nach dem Wert
# wir mussten auf die ersten 100 Artikel beschränken, da sonst Memory Error

sns.set()

sorted_scores = sorted(tfidf_scores(us_dataframe['Article'].head(100)).items(), key=lambda x: x[1], reverse=True)

# sorted_scores[:10], um nur die Top 10 Wörter zu plotten
# außerdem wird der TF-IDF-Wert auf 5 Nachkommastellen gerundet

words = [x[0] for x in sorted_scores[:10]]
values = [round(x[1], 5) for x in sorted_scores[:10]]
mybar = plt.bar(words, values, alpha=0.5, color="green")

# y-Achsen-Limit musste an den maximalen TF-IDF-Wert in values angepasst werden, 
# da sonst Grafik zu groß oder zu klein wurde

axes = plt.gca()
axes.set_ylim(ymin = 0, ymax = (0.005 + max(values)))   

plt.xlabel("Top Words", fontsize=15)
plt.ylabel("TF-IDF", fontsize=15)
plt.title('Top 10 words based on TF-IDF value - US', fontsize=15)

# aktuelle Größe
fig_size = plt.rcParams["figure.figsize"]
# Größe anpassen 
fig_size[0] = 12
fig_size[1] = 9
plt.rcParams["figure.figsize"] = fig_size

plt.show()

### Berechnung der Vektoren ###

### Initialisert einen Countvektor und weißt der Variable Vectors einen Vektor zu der aus den 100 ersten Artikeln
### aus dem uk_dataframe besteht. Hier verwenden wir die 100 ersten Artikel, da es sonst zu einem Memory Error kommt, wie bereits
### in der Dokumentation beschrieben. Zusätzlich erzeugen wir ein Vokabular mit unique Wörtern.

#vecorizer = HashingVectorizer()
vectorizer = CountVectorizer()
Vectores = vectorizer.fit_transform(us_dataframe["Article"].head(100)).todense()
vocab = vectorizer.get_feature_names()

### In der Methode searchedword suchen wir nach der Anzahl an Vorkomnissen eines
### speziellen Wortes in einem bestimmten Artikel auf Grundlage des vorher erzeugten Vektors. 

def searchedword(word, articlenumber):
    searched_word = list(vocab).index(word)
    return(Vectores[articlenumber, searched_word])

wortsuche("say", 1)

### Berechnet die euklidische Distanz auf Grundlage des erzeugtem Vektors. ###
### Um so größer die Zahl ist, desto unterschiedlicher sind die Artikel zu einander.
### Damit wir gut zu lesende Werte bekommen, runden wir auf die dritte Nachkommastelle.

eukdist = euclidean_distances(Vectores) 
np.round(eukdist, 3)

### Berechnet die cosinus Distanz auf Grundlage des erzeugtem Vektors. ###
### Um so größer die Zahl, desto unterschieldicher sind die Artikel zu einander (wird durch das -1 erreicht)

cosdist = 1 - cosine_similarity(Vectores) # 
np.round(cosdist, 3)


### Gleiche Funktion ohne die minus 1, daher gilt, um so größer die Zahl, desto ähnlicher sind die Artikel.

cossim = cosine_similarity(Vectores) 
np.round(cossim, 3)

### Multidimensional Scaling: Entfernung zwischen Punkten ist proportional zur paarweisen Entfernungen. ###

### Wir geben zwei Komponenten an, damit wir die Punkte in einer zweidimensionalen Ebene zeichnen können.
### Desweiteren müssen wir diese vorberechnen, weil wir eine Entfernungsmatrix erzeugen wollen.
### Schlussendlich wandeln wir die Cosinus Distanz in ein MDS Modell um.

### 1. Versuch nur mit einer CosDis ###

mds = MDS(n_components=2, dissimilarity="precomputed", random_state=1)
pos = mds.fit_transform(cosdist)
xs, ys = pos[:, 0], pos[:, 1]

### Zeichnet das Diagramm.

for x, y, name in zip(xs, ys, names):
        color = "green" 
        plt.scatter(x, y, c=color)
        plt.text(x, y, "")
  
### Visualisierung der Skalierung und des Diagrammes.

fig_size = plt.rcParams["figure.figsize"]

fig_size[0] = 12
fig_size[1] = 9
plt.rcParams["figure.figsize"] = fig_size

plt.show()


### 1. Versuch nur mit mehreren CosDis (Zweischen den Ländern) ###

# AU CosDis
vectorizer2 = CountVectorizer(max_features=5000)
Vectores2 = vectorizer2.fit_transform(au_dataframe["Article"].head(200)).todense()
cosdist2 = 1 - cosine_similarity(Vectores2) # Um so größer die Zahl, desto Unterschieldicher sind die Artiekl (Wird durch das -1 erreicht)
np.round(cosdist2, 3)

# UK CosDis
vectorizer3 = CountVectorizer(max_features=5000)
Vectores3 = vectorizer3.fit_transform(uk_dataframe["Article"].head(200)).todense()
cosdist3 = 1 - cosine_similarity(Vectores3) # Um so größer die Zahl, desto Unterschieldicher sind die Artiekl (Wird durch das -1 erreicht)
np.round(cosdist3, 3)


mds = MDS(n_components=2, dissimilarity="precomputed", random_state=1)
pos = mds.fit_transform(cosdist)
pos2 = mds.fit_transform(cosdist2)
pos3 = mds.fit_transform(cosdist3)
xs, ys = pos[:, 0], pos[:, 1]
xs2, ys2 = pos2[:, 0], pos2[:, 1]
xs3, ys3 = pos3[:, 0], pos3[:, 1]

#names = [a for a in (us_dataframe["Article"].head(100))]
for x, y in zip(xs, ys):
        plt.scatter(x, y, c="orange")
  
for x, y in zip(xs2, ys2):
    plt.scatter(x, y, c="green")
        
for x, y in zip(xs3, ys3):
    plt.scatter(x, y, c="yellow")

plt.legend()
    
fig_size = plt.rcParams["figure.figsize"]
# set figure width to 12 and height to 9 
fig_size[0] = 12
fig_size[1] = 15
plt.rcParams["figure.figsize"] = fig_size

plt.show()


### Ward Methode: Hierarchisches Clustering ###

### Wir rufen unsere Cosinus Distanz mit der Ward Funktion auf und ordnen die Artikel im Cluster an.

linkage_matrix = ward(cosdist)
dendrogram(linkage_matrix, orientation="left") 

### Behebt die Fehler mit den Rändern und zeichnet das Diagram.

plt.tight_layout()
plt.show()

# Grafik der dist-Matrix, je dunkler die Farbe desto kleiner die Distanz und desto ähnlicher die Artikel ###
# Achsen zeigen Artikel-Nr. an
# m ersetzen mit der Matrix die wir beim euclidean/cosine distance rausbekommen, das mit den Nullen in der Diagonalen

m = [[0.0, 1.47, 2.43, 3.44, 1.08, 2.83, 1.08, 2.13, 2.11, 3.7], [1.47, 0.0, 1.5, 2.39, 2.11, 2.4, 2.11, 1.1, 1.1, 3.21], 
     [2.43, 1.5, 0.0, 1.22, 2.69, 1.33, 3.39, 2.15, 2.12, 1.87], [3.44, 2.39, 1.22, 0.0, 3.45, 2.22, 4.34, 2.54, 3.04, 2.28], 
     [1.08, 2.11, 2.69, 3.45, 0.0, 3.13, 1.76, 2.46, 3.02, 3.85], [2.83, 2.4, 1.33, 2.22, 3.13, 0.0, 3.83, 3.32, 2.73, 0.95], 
     [1.08, 2.11, 3.39, 4.34, 1.76, 3.83, 0.0, 2.47, 2.44, 4.74], [2.13, 1.1, 2.15, 2.54, 2.46, 3.32, 2.47, 0.0, 1.78, 4.01], 
     [2.11, 1.1, 2.12, 3.04, 3.02, 2.73, 2.44, 1.78, 0.0, 3.57], [3.7, 3.21, 1.87, 2.28, 3.85, 0.95, 4.74, 4.01, 3.57, 0.0]]
matrix = numpy.matrix(m)
matrix

# ka was die nächsten 3 Zeilen tun
#fig = plt.figure()
#ax = fig.add_subplot(1,1,1)
#ax.set_aspect('equal')

plt.imshow(cosdist, interpolation='nearest', cmap=plt.cm.Blues_r)
plt.gca().xaxis.tick_top()
plt.colorbar()

# Grafik der dist-Matrix, je dunkler die Farbe desto kleiner die Distanz und desto ähnlicher die Artikel ###
# Achsen zeigen Artikel-Nr. an
# m ersetzen mit der Matrix die wir beim euclidean/cosine distance rausbekommen, das mit den Nullen in der Diagonalen


plt.imshow(eukdist, interpolation='nearest', cmap=plt.cm.Blues_r)
plt.gca().xaxis.tick_top()
plt.colorbar()

### Weitere Ähnlichkeitsvisualisierung von Artikeln auf Grundlage der cosdist

sns.reset_orig()
plt.imshow(cosdist_zw, interpolation='nearest', cmap=plt.cm.Blues_r)
plt.gca().xaxis.tick_top()
plt.colorbar()